#include <SFML/Graphics.hpp>

int main()
{
    sf::RenderWindow window(sf::VideoMode(300, 300), "SFML works!");
    // To use less CPU, we limit framerate to 30 fps
    // (On Michel Simatic's PC, under Windows, the execution of this code
    // drops down from 9% of CPU (without window.setFramerateLimit(30);)
    // to 0,2% de CPU (with window.setFramerateLimit(30);).
    // We could have preferred to use window.setVerticalSyncEnabled(true)
    // as mentionned in https://www.sfml-dev.org/tutorials/2.5/window-window-fr.php#contrcler-le-framerate
    // But, on Linux (WSL2) used by Michel Simatic, there is the error 
    // message "Setting vertical sync not supported" displayed by SFML: 
    // This message signifies that window.setVerticalSyncEnabled(true)
    // instruction cannot be considered on this Linux.
    window.setFramerateLimit(30);
    
    sf::CircleShape shape(150.F);
    shape.setFillColor(sf::Color::Green);

    while (window.isOpen())
    {
        sf::Event event;
        while (window.pollEvent(event))
        {
            if (event.type == sf::Event::Closed)
                window.close();
            // Catch the resize events
            if (event.type == sf::Event::Resized)
            {
                // Update the view to the new size of the window, so that contents is not distorted by resizing
                // See https://www.sfml-dev.org/tutorials/2.6/graphics-view.php#showing-more-when-the-window-is-resized
                sf::FloatRect visibleArea(0.f, 0.f, event.size.width, event.size.height);
                window.setView(sf::View(visibleArea));
            }
        }
        window.clear();
        window.draw(shape);
        window.display();
    }

    return 0;
}
